@@ -29,7 +29,7 @@ from strawberry.type import (
     StrawberryTypeVar,
 )
 from strawberry.types.types import TypeDefinition
-from strawberry.unset import _Unset
+from strawberry.unset import UNSET
 from strawberry.utils.typing import is_generic, is_type_var
 
 
@@ -123,7 +123,7 @@ class StrawberryAnnotation:
         types = evaled_type.__args__
         non_optional_types = tuple(
             filter(
-                lambda x: x is not type(None) and x is not _Unset,  # noqa: E721
+                lambda x: x is not type(None) and x is not type(UNSET),  # noqa: E721
                 types,
             )
         )
