@@ -4,12 +4,20 @@ import dataclasses
 import inspect
 import sys
 from itertools import islice
-from typing import Callable, List, Optional, TypeVar
+from typing import Any, Callable, List, Optional, TypeVar
 
 from graphql import DirectiveLocation
 
 from strawberry.annotation import StrawberryAnnotation
 from strawberry.arguments import StrawberryArgument
+from strawberry.field import StrawberryField
+
+
+def directive_field(name: str) -> Any:
+    return StrawberryField(
+        python_name=None,
+        graphql_name=name,
+    )
 
 
 @dataclasses.dataclass
